
# A toolkit for natural language processing

## Features

### API integration

* automatic translation
* automatic abbreviation

### Service interface

* machine translation
* dialogue system
* argumentation mining
* annotation system

